AppButtonIosAndroid class
A cross-platform action button that renders a native iOS AppIosButton on iOS and a Material circular button on all other platforms.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AppButtonIosAndroid
Constructors
- AppButtonIosAndroid({Key? key, VoidCallback? onPressed, String? symbol, bool isOutline = false, IconData? icon, Color? color, double? buttonSize})
-
const
Properties
-
Custom tap-target size. Defaults to
AppDimensions.iconXL - 6.final - color → Color?
-
Tint / foreground color applied to the icon and button surface.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
Material icon — used on Android / other platforms.
final
- isOutline → bool
-
When
true, renders a bordered outline style on Android.final - key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onPressed → VoidCallback?
-
Called when the button is tapped. Pass
nullto disable the button.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String?
-
SF Symbol name — required on iOS.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited